@@ -1,12 +1,12 @@
 package WordList::Test::OneTwo;
 
 our $DATE = '2020-05-23'; # DATE
-our $VERSION = '0.7.1'; # VERSION
+our $VERSION = '0.7.2'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("avg_word_len",3,"num_words_contains_unicode",0,"num_words_contains_nonword_chars",0,"longest_word_len",3,"num_words_contain_whitespace",0,"shortest_word_len",3,"num_words_contain_nonword_chars",0,"num_words_contains_whitespace",0,"num_words_contain_unicode",0,"num_words",2); # STATS
+our %STATS = ("num_words",2,"shortest_word_len",3,"num_words_contains_unicode",0,"num_words_contains_nonword_chars",0,"num_words_contain_whitespace",0,"num_words_contains_whitespace",0,"longest_word_len",3,"num_words_contain_unicode",0,"num_words_contain_nonword_chars",0,"avg_word_len",3); # STATS
 
 1;
 # ABSTRACT: Wordlist that contains "one" and "two"
@@ -21,7 +21,7 @@ WordList::Test::OneTwo - Wordlist that contains "one" and "two"
 
 =head1 VERSION
 
-This document describes version 0.7.1 of WordList::Test::OneTwo (from Perl distribution WordList), released on 2020-05-23.
+This document describes version 0.7.2 of WordList::Test::OneTwo (from Perl distribution WordList), released on 2020-05-23.
 
 =head1 SYNOPSIS
 
